@@ -22,7 +22,17 @@
 
 #pragma once
 
+struct config_t
+{
+    char *path;
+    char *active_group;
+    char *device;
+};
+
+extern struct config_t config;
+
 void config_file_print(void);
 void config_file_parse(void);
 void config_exit(void);
-void config_file_show_sub_configurations(void);
+void config_file_show_profiles(void);
+void config_list_targets(void);
